#
# spec file for package cglm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
Name:           cglm
Version:        0.9.4
Release:        1.5
Summary:        OpenGL mathematics (glm) for C
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/recp/cglm
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  python3-Sphinx
BuildRequires:  python3-sphinx_rtd_theme
ExcludeArch:    %{ix86}

%description
cglm is a C99-compatible version of the previous OpenGL Mathematics
(GLM) implementation, a mathematics library for graphics software
based on the OpenGL Shading Language (GLSL) specifications.

%package -n libcglm%{sover}
Summary:        OpenGL mathematics (glm) for C
Group:          System/Libraries

%description -n libcglm%{sover}
cglm is a C99-compatible version of the previous OpenGL Mathematics
(GLM) implementation, a mathematics library for graphics software
based on the OpenGL Shading Language (GLSL) specifications.

%package devel
Summary:        Header files for C OpenGL Mathematics
Group:          Development/Libraries/C and C++
Requires:       libcglm%{sover} = %{version}

%description devel
This package contains development files for cglm.

%package devel-doc
Summary:        Documentation for C OpenGL Mathematics
Group:          Documentation/HTML
BuildArch:      noarch

%description devel-doc
This package contains documentation files for cglm.

%prep
%autosetup -p1

%build
%meson -Dbuild_tests=true
%meson_build
cd docs
sphinx-build source html
rm -rf html/.{buildinfo,doctrees,nojekyll}
%fdupes html

%install
%meson_install
%fdupes %{buildroot}/%{_prefix}
%fdupes -s docs/html

%check
%meson_test

%post -n libcglm%{sover} -p /sbin/ldconfig
%postun -n libcglm%{sover} -p /sbin/ldconfig

%files -n libcglm%{sover}
%license LICENSE
%{_libdir}/libcglm.so.%{sover}*

%files devel
%doc README.md CREDITS
%{_includedir}/cglm
%{_libdir}/libcglm.so
%{_libdir}/pkgconfig/cglm.pc

%files devel-doc
%doc docs/html

%changelog
* Mon Apr  8 2024 jun wang <jgwang@suse.com>
- Update to version 0.9.4
  + Changes from 0.9.4
  * #402: Struct API glms_ray_at incorrect dir param
  * dont use I macro defined in standard(fixes #404)
  * #403: mat2x3: fix multiplication functions
  * #405: mat2x4: fix multiplication functions
  * #407: mat3x2: fix multiplication functions
  * #408: mat3x4: fix multiplication functions
  * #410: mat4x2: fix multiplication functions
  * #411: mat4x3: fix multiplication functions
  * docs: improve docs
  * #412: separate SSE and SSE2
  * make Fasth math work both on SSE and SSE2, make -0.0f run
    on SSE + fast math
  * make some failing test pass when fast math is on
  * tests: dont validate nan and inf on fast math
  * docs: add note to enable config where may not work is some
    environments
  * docs: alignment
  * fix some doc typos & warnings
  + Changes from 0.9.2
  * #378: win32, simd: ensure we are on msvc when checking
    MSVC specific headers
  * win32, tests: fix drand48() error on mingw
  * #379: simd: min / max helpers
  * docs: update read the docs package versions
  * #381: add new functions for ivec2 and ivec3
    (dot, norm, norm2, div, divs, mod...)
  * #383: implement struct API for ivec2, ivec3, and ivec4
  * #384: docs, fix typos
  * #386: add additional CI via GitHub Actions
  * #388: ci: Remove appveyor
  * #387: suppress warnings
  * #389: aabb2d: fix struct api
  * #390: doc improvements
  * #391: ci: Add ARM64 UWP for WindowsStore
  * #392: aabb2d_zero, aabb2d_diagonal and aabb2d_size
  * #395: use NDEBUG to check DEBUG mode, update cmake to
    respect DEBUG
  * suppress warnings: C4244: 'function': conversion from
    'int' to 'float'
  * test: fix ivec2 and ivec3 comparison and suppress warnings
  * #398: allow passing const float* to make functions
  * #397: clarify some rotation rules, update docs to explain
    rotate() a bit more
  * #399: some missing ray functions
  * improving handling of very small vectors to prevent
    instability and overflow
  * build: add missing files
  * fix some doc typos & warnings
* Mon Mar 18 2024 Dirk Müller <dmueller@suse.com>
- update to 0.9.2:
  * aabb2d and euler to quat
  * new subtraction family of vector functions
  * and many others improvements and bugfixes
* Thu Nov  9 2023 Dirk Müller <dmueller@suse.com>
- update to 0.9.1:
  * Now we have **mat2x3**, **mat2x4**, **mat3x2**, **mat3x4**,
  * *mat4x2** and **mat4x3** types and its functions
  * README: add build docs for WebAssembly
  * io: fix test runner.c implicit declaration glm_arch_print
  * https://github.com/recp/cglm/pull/309: fix and improve
    CGLM_USE_ANONYMOUS_STRUCT definition with more robust
    compiler version check
  * suppress sign conversion warnings
  * Implement missing 3D
    Affine Transforms in the Struct API
  * drop "-Werror" to allow skip warnings on production build
  * more robust __builtin_assume_aligned detection
  * reduce glms_mat[4|3|2]_make()'s dest parameter
  * fix and improve printing arch name in tests
  * make GLM_TESTS_NO_COLORFUL_OUTPUT work on non-test print
    colors too
  * Now we have WASM 128 SIMD support
  * `CGLM_OMIT_NS_FROM_STRUCT_API`, omits CGLM_STRUCT_API_NS
    (glms_) namespace  completely if there is sub namespace e.g
    mat4_, vec4_ ... **DEFAULT** is not defined
  * `CGLM_STRUCT_API_NS`: define name space for struct api,
  * *DEFAULT** is `glms`
  * `CGLM_STRUCT_API_NAME_SUFFIX`: define name suffix,
  * *DEFAULT** is empty e.g `defining it as #define
    CGLM_STRUCT_API_NAME_SUFFIX  s` will add `s` suffix to
    `mat4_mul -> mat4s_mul`
* Wed Feb 15 2023 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8.9
  * Adding initialization macros for ivec types
  * Make implicit double promotion/casting explicit
* Fri Dec 23 2022 Dirk Müller <dmueller@suse.com>
- update to v0.8.8:
  New features:
  * new abs functions for vec2, ivec2, ivec3, ivec4
  Bugfixes and Improvements:
  * fix assertion in test_clamp on x86
  * fix missing abs declaration on Emscripten
  * switch CMAKE_BINARY_DIR to CMAKE_CURRENT_BINARY_DIR for cmake.pc
  * see previous releases for more
* Sun Nov 20 2022 Mia Herkt <mia@0x0.st>
- Update to version 0.8.7
  * fix build: add missing struct affine functions and headers
- Changes in 0.8.6:
  New features:
  * new affine transform and project functions
    gh#recp/cglm#260
  * add basic ivec functions
    gh#recp/cglm#251
  Bugfixes and improvements:
  * added missing include in io.h which adds GLM_MAX macro
    gh#recp/cglm#257
  * update README to show that integer types are supported
    gh#recp/cglm#254
  * fix grammatical errors in docs index
    gh#recp/cglm#247
  * some improvements including build files
- Changes in 0.8.5:
  * update GLM_FLT_EPSILON to use 1e-5 instead of 1e-
  * implement a few complex routines
  * header containing sse3 intrinsics is pmmintrin.h
  * add missing ivec types
  * extend unions for struct api
  * fix glm_pickmatrix()'s param type
  * fix a bug in glm_lookat_lh
  * fix bug in view_lh.h
  * some improvements including build files
* Tue May 17 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8.5
  * update GLM_FLT_EPSILON to use 1e-5 instead of 1e-
  * implement a few complex routines
  * set PACKAGE_VERSION so it gets substituted in cglm.pc.in by cmake
  * header containing sse3 intrinsics is pmmintrin.h
  * add missing ivec types
  * fix a bug in glm_lookat_lh and view_lh.h
- Update to version 0.8.4
  * Now there are _no and _zo vesions of project / unproject functions.
  * If CGLM_CLIPSPACE_INCLUDE_ALL is defined then all clipspace
    headers are icluded in project.h or related main headers
  * add ZERO_TO_ONE support to glm_unprojecti
  * add ZERO_TO_ONE support to glm_project
  * new function: glm_pickmatrix() aka gluPickMatrix()
  * fix vec3_ortho
  * fix cross product when an operand is also dest
  * compute quaternion rotating a vector into another
* Fri Jun  4 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8.3
  * cglm now supports different clipspace configurations.
  * new: nlerp for quaternions
  * simd, and sse optimizations
  * arm, and neon: improvements
  * style: rename nearVal, farVal to nearZ and farZ
  * many other improvements
- Drop cglm-set-soversion.patch, upstream fixed
* Tue May 11 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Exclude ix86, as it will fail
* Tue May  4 2021 Jan Engelhardt <jengelh@inai.de>
- Trim boasting from description.
- Run fdupes.
* Tue May  4 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.8.2
  * rename glmm_shuff1x() to glmm_splat()
  * mark glmm_shuff1x() as DEPRECATED
  * optimize translate functions with FMA and NEON
  * use unified glmm api for vec4
- Update to version 0.8.1
  * Implement FMA: SIMD operations are optimized with FMA
    instructions to reduce operations and increasee accuracy.
    The gennerated CPU instructions are reduced.
  * optimize mat4 SSE operations with FMA
  * optimize mat3 SSE operations with FMA
  * optimize mat2 SSE operations with FMA
  * optimize affine mat SSE operations with FMA
  * optimize vec4 muladd and muladds operations with FMA
  * New glmm functions (SSE + NEON + AVX)
* Mon Apr 19 2021 Mia Herkt <mia@0x0.st>
- Disable -Werror
* Sun Apr 18 2021 Mia Herkt <mia@0x0.st>
- init, 0.8.0
